@@ -2,10 +2,11 @@
 #define AWORKSPACES_H_
 
 #include "ywindow.h"
-#include "ybutton.h"
+#include "obj.h"
+#include "objbutton.h"
 #include "ytimer.h"
 
-class WorkspaceButton: public YButton, public YTimerListener {
+class WorkspaceButton: public ObjectButton, public YTimerListener {
 public:
     WorkspaceButton(long workspace, YWindow *parent);
 
@@ -16,7 +17,7 @@ public:
     virtual bool handleTimer(YTimer *t);
 
     virtual void actionPerformed(YAction *button, unsigned int modifiers);
-    virtual YFont * getFont();
+    virtual ref<YFont> getFont();
     virtual YColor * getColor();
     virtual YSurface getSurface();
 
@@ -30,8 +31,8 @@ private:
     static YColor * activeButtonBg;
     static YColor * activeButtonFg;
 
-    static YFont * normalButtonFont;
-    static YFont * activeButtonFont;
+    static ref<YFont> normalButtonFont;
+    static ref<YFont> activeButtonFont;
 };
 
 class WorkspacesPane: public YWindow {
@@ -39,17 +40,19 @@ public:
     WorkspacesPane(YWindow *parent);
     ~WorkspacesPane();
 
+    void configure(const YRect &r, const bool resized);
+
     WorkspaceButton *workspaceButton(long n);
 private:
     WorkspaceButton **fWorkspaceButton;
 };
 
-extern YPixmap *workspacebuttonPixmap;
-extern YPixmap *workspacebuttonactivePixmap;
+extern ref<YPixmap> workspacebuttonPixmap;
+extern ref<YPixmap> workspacebuttonactivePixmap;
 
 #ifdef CONFIG_GRADIENTS
-extern class YPixbuf *workspacebuttonPixbuf;
-extern class YPixbuf *workspacebuttonactivePixbuf;
+extern ref<YPixbuf> workspacebuttonPixbuf;
+extern ref<YPixbuf> workspacebuttonactivePixbuf;
 #endif
 
 #endif
