@@ -55,6 +55,9 @@ XIV(bool, taskBarLaunchOnSingleClick,           true)
 XIV(bool, taskBarShowCollapseButton,            true)
 #endif
 XIV(bool, minimizeToDesktop,                    false)
+XIV(bool, miniIconsPlaceHorizontal,             false)
+XIV(bool, miniIconsRightToLeft,                 false)
+XIV(bool, miniIconsBottomToTop,                 false)
 XIV(bool, manualPlacement,                      false)
 XIV(bool, smartPlacement,                       true)
 XIV(bool, centerTransientsOnOwner,              true)
@@ -193,6 +196,12 @@ cfoption icewm_preferences[] = {
     OBV("ShowMoveSizeStatus",                   &showMoveSizeStatus,            "Show position status window during move/resize"),
     OBV("ShowWorkspaceStatus",                  &workspaceSwitchStatus,         "Show name of current workspace while switching"),
     OBV("MinimizeToDesktop",                    &minimizeToDesktop,             "Display mini-icons on desktop for minimized windows"),
+    OBV("MiniIconsPlaceHorizontal",             &miniIconsPlaceHorizontal,
+"Place the mini-icons horizontal instead of vertical"),
+    OBV("MiniIconsRightToLeft",                 &miniIconsRightToLeft,
+"Place new mini-icons from right to left"),
+    OBV("MiniIconsBottomToTop",                 &miniIconsBottomToTop,
+"Place new mini-icons from bottom to top"),
     OBV("StrongPointerFocus",                   &strongPointerFocus,            "Always maintain focus under mouse window (makes some keyboard support non-functional or unreliable"),
     OBV("OpaqueMove",                           &opaqueMove,                    "Opaque window move"),
     OBV("OpaqueResize",                         &opaqueResize,                  "Opaque window resize"),
@@ -429,6 +438,7 @@ cfoption icewm_preferences[] = {
     OKV("KeySysHideAll",                        gKeySysHideAll,                 ""),
     OKV("KeySysUndoArrange",                    gKeySysUndoArrange,             ""),
     OKV("KeySysShowDesktop",                    gKeySysShowDesktop,             ""),
+    OKV("KeySysCollapseTaskBar",                gKeySysCollapseTaskBar,         ""),
 #endif
     OKF("WorkspaceNames", addWorkspace, ""),
     OK0()
