@@ -25,8 +25,8 @@ AboutDlg *aboutDlg = 0;
 AboutDlg::AboutDlg(): YDialog() {
     char const *version("IceWM "VERSION" ("HOSTOS"/"HOSTCPU")");
     char *copyright(strJoin("Copyright ", _("(C)"), " 1997-2004 Marko Macek, ",
-			                   _("(C)"), " 2001 Mathias Hasselmann",
-					   NULL));
+                            _("(C)"), " 2001 Mathias Hasselmann",
+                            NULL));
 
     fProgTitle = new YLabel(version, this);
     fCopyright = new YLabel(copyright, this);
@@ -134,8 +134,9 @@ void AboutDlg::showFocused() {
     if (getFrame() == 0)
         manager->manageClient(handle(), false);
     if (getFrame() != 0) {
-        getFrame()->setPosition(dx + dw / 2 - getFrame()->width() / 2,
-                                dy + dh / 2 - getFrame()->height() / 2);
+        getFrame()->setNormalPositionOuter(
+            dx + dw / 2 - getFrame()->width() / 2,
+            dy + dh / 2 - getFrame()->height() / 2);
         getFrame()->activate(true);
     }
 }
