@@ -681,9 +681,12 @@ static void initMenus() {
 #ifndef NO_CONFIGURE_MENUS
             YStringArray noargs;
 
-            logoutMenu->addItem(_("Lock _Workstation"), -2, "", actionLock);
-            logoutMenu->addItem(_("Re_boot"), -2, "", actionReboot);
-            logoutMenu->addItem(_("Shut_down"), -2, "", actionShutdown);
+            if (canLock())
+                logoutMenu->addItem(_("Lock _Workstation"), -2, "", actionLock);
+            if (canShutdown(true))
+                logoutMenu->addItem(_("Re_boot"), -2, "", actionReboot);
+            if (canShutdown(false))
+                logoutMenu->addItem(_("Shut_down"), -2, "", actionShutdown);
             logoutMenu->addSeparator();
 
             DProgram *restartIcewm =
