@@ -69,7 +69,7 @@ YButton::~YButton() {
             removeAccelerator(hotKey, xapp->AltMask, this);
     }
     popdown();
-    delete fText; fText = 0;
+    delete[] fText; fText = 0;
 }
 
 void YButton::paint(Graphics &g, int const d, const YRect &r) {
@@ -147,7 +147,7 @@ void YButton::paintFocus(Graphics &g, const YRect &/*r*/) {
             { dp, dp + height() - ds - 1, width() - ds, 1 }
         };
 
-        g.setClipRects(0, 0, focus, 4, YXSorted);
+        g.setClipRectangles(focus, 4);
 
         if (wmLook == lookMetal)
             paint(g, 0, YRect(dp, dp, width() - ds, height() - ds));
@@ -321,6 +321,7 @@ void YButton::setText(const char *str, int hotChar) {
         if (xapp->AltMask != 0)
             removeAccelerator(hotKey, xapp->AltMask, this);
     }
+    if (fText != 0) { delete[] fText; fText = 0; }
     fText = newstr(str);
     /// fix
     if (fText) {
@@ -346,7 +347,8 @@ void YButton::setText(const char *str, int hotChar) {
                 installAccelerator(hotKey, xapp->AltMask, this);
         }
 
-        setSize(3 + w + 4 + 2, 3 + h + 4 + 2);
+        if (fImage == null)
+            setSize(3 + w + 4 + 2, 3 + h + 4 + 2);
     } else
         hotKey = -1;
 }
