@@ -3,6 +3,7 @@
 #ifdef CONFIG_COREFONTS
 
 #include "ypaint.h"
+#include "sysdep.h"
 
 #include "intl.h"
 #include "yxapp.h"
@@ -151,7 +152,7 @@ XFontSet YFontSet::getFontSetWithGuess(char const * pattern, char *** missing,
     if (*nMissing) XFreeStringList(*missing);
 
     if (None == fontset) { // --- get a fallback fontset for pattern analyis ---
-#warning "remove this broken locale switching"
+/// TODO #warning "remove this broken locale switching"
         char const * locale(setlocale(LC_CTYPE, NULL));
         setlocale(LC_CTYPE, "C");
 
