@@ -119,7 +119,7 @@ YXftFont::YXftFont(const char *name, bool use_xlfd):
             XftFontOpen(xapp->display(), xapp->screen(),
                         XFT_FAMILY, XftTypeString, "sans-serif",
                         XFT_PIXEL_SIZE, XftTypeInteger, 12,
-                        0);
+                        NULL);
 
         if (NULL != sans) {
             delete[] fFonts;
