@@ -89,18 +89,19 @@ private:
 
     void drawSubmenuArrow(Graphics &g, YMenuItem *mitem, 
                           int left, int top);
-    void paintItem(Graphics &g, int i, int &l, int &t, int &r, 
-                   int minY, int maxY, bool draw);
+    void paintItem(Graphics &g, const int i, const int l, const int t, const int r,
+                   const int minY, const int maxY, bool draw);
 
+    void repaintItem(int item);
     void paintItems();
-    int findItemPos(int item, int &x, int &y);
+    int findItemPos(int item, int &x, int &y, int &h);
     int findItem(int x, int y);
     int findActiveItem(int cur, int direction);
     int findHotItem(char k);
     void focusItem(int item);
     void activateSubMenu(int item, bool byMouse);
 
-    int activateItem(int no, int modifiers, bool byMouse = false);
+    int activateItem(int modifiers, bool byMouse = false);
     bool isCondCascade(int selectedItem);
     int onCascadeButton(int selectedItem, int x, int y, bool checkPopup);
 
