@@ -442,7 +442,7 @@ void Graphics::drawStringEllipsis(int x, int y, const char *str, int maxWidth) {
 }
 
 void Graphics::drawCharUnderline(int x, int y, const char *str, int charPos) {
-#warning "FIXME: don't mess with multibyte here, use a wide char"
+/// TODO #warning "FIXME: don't mess with multibyte here, use a wide char"
     int left = 0; //fFont ? fFont->textWidth(str, charPos) : 0;
     int right = 0; // fFont ? fFont->textWidth(str, charPos + 1) - 1 : 0;
     int len = strlen(str);
@@ -619,19 +619,6 @@ void Graphics::setFunction(int function) {
     XSetFunction(fDisplay, gc, function);
 }
 
-void Graphics::setClipRects(int x, int y, XRectangle rectangles[], int n,
-                            int ordering) {
-    XSetClipRectangles(fDisplay, gc, x - xOrigin, y - yOrigin, rectangles, n, ordering);
-}
-
-void Graphics::setClipMask(Pixmap mask) {
-    XSetClipMask(fDisplay, gc, mask);
-}
-
-void Graphics::setClipOrigin(int x, int y) {
-    XSetClipOrigin(fDisplay, gc, x - xOrigin, y - yOrigin);
-}
-
 /******************************************************************************/
 
 void Graphics::drawImage(const ref<YIconImage> &image, int const x, int const y) {
@@ -1072,6 +1059,10 @@ void Graphics::setClipRectangles(XRectangle *rect, int count) {
 #endif
 }
 
+void Graphics::setClipMask(Pixmap mask) {
+    XSetClipMask(fDisplay, gc, mask);
+}
+
 void Graphics::resetClip() {
     XSetClipMask(xapp->display(), gc, None);
 #ifdef CONFIG_XFREETYPE
