@@ -8,6 +8,8 @@ public:
     virtual void socketConnected() = 0;
     virtual void socketError(int err) = 0;
     virtual void socketDataRead(char *buf, int len) = 0;
+protected:
+    virtual ~YSocketListener() {};
 };
 
 class YSocket: public YPoll {
